echo "Installing packages from INIT"
#pip uninstall --yes refractio
#pip uninstall --yes pandas
#pip install --upgrade pip
#pip install feast==0.34.1
#pip install snowflake-snowpark-python==1.6.1
#pip install feast
#pip install 'feast[snowflake]'
#psycopg2-binary==2.9.1
echo "Done with dependency installation!";